OiRA

Help

1. Suunnittelu
2. Osallistuminen ja yhteistyö
3. Tunnistaminen + Arviointi
4. Toimintasuunnitelma
   1. 1.1.1 Slips, trips and falls are not prevented.
   2. 1.1.2 Collisions, bumps, and jamming are not prevented.
   3. 1.1.4 Exposure to noise is neither prevented nor controlled.
   4. 1.1.6 Exposure to biological substances is neither prevented nor controlled
   5. Ω.1 The entrance floor is often wet
   6. Title of the first custom risk
   7. This is another custom risk added by the user
   - kehitettävää
5. Raportti
6. Riskinarvioinnin tila 9%

# Commercial guarding, Leicester

Riskien arvioinnin perusteella laaditaan toimintasuunnitelma. Määrittele toimintasuunnitelmaan ne käytännön toimenpiteet, joilla tunnistamiesi riskien hallinta toteutuu.

Huomioi toimintasuunnitelmaa tehdessäsi:

1. Onko riski vältettävissä? Voiko sen poistaa kokonaan? Arvioi
   - Onko vaaraa tai haittaa aiheuttava työtehtävä tai työvaihe tarpeellinen?
   - Onko vaara- tai haittatekijä mahdollista poistaa?
2. Jos työssä esiintyvien vaara- ja haittatekijöiden aiheuttamia riskejä ei voida poistaa tai välttää, niin millaisin keinoin ne saadaan sellaiselle tasolle, etteivät ne aiheuta vaaraa terveydelle ja turvallisuudelle?

Kuvaa toimintasuunnitelmaan kaikki ne toimenpiteet, joilla kunkin arvioimasi riskin voi poistaa tai sen aiheuttamaa haittaa pienentää. Muista myös mainita näihin toimenpiteisiin tarvittava asiantuntemuksen taso ja/tai muut vaatimukset. Toimintasuunnitelmaa luodessasi voit käyttää apunasi sovelluksen tarjoamia toimenpiteitä, muokata niitä tarpeen mukaan tai kirjata muita tarvittavia toimenpiteitä.

Luo toimintasuunnitelma

Scroll to top
Back

## action-plan-landing.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More